import dash_bootstrap_components as dbc
from dash import html
from dash.development.base_component import Component

from amora.models import Model


def component(model: Model) -> Component:
    return html.Span(
        [
            dbc.Badge(f"{key}: {value}", color="info")
            for key, value in model.__model_config__.labels.items()
        ]
    )



import dash_table

from amora.models import Model
from amora.providers.bigquery import sample


def component(model: Model) -> dash_table.DataTable:
    df = sample(model, percentage=1)
    return dash_table.DataTable(
        data=df.to_dict("records"),
        columns=[{"name": col, "id": col} for col in sorted(df.columns.values)],
        export_format="csv",
        sort_action="native",
    )
